@@ -7,7 +7,7 @@ use crate::utils::syn::{named_fields, parse_derive_input};
 pub(crate) fn all_args_constructor(input: TokenStream) -> TokenStream {
     let derive_input = parse_derive_input(input);
 
-    let name = &derive_input.ident.clone();
+    let name = &derive_input.ident;
     let (impl_generics, ty_generics, where_clause) = &derive_input.generics.split_for_impl();
     let fields = named_fields(&derive_input);
 
